==> pyimage2pdf-1.0.0-py3-none-any.whl: pyimage2pdf/CommandClass.py <==

from logging import Logger
from logging import getLogger

from pathlib import Path

from PIL import UnidentifiedImageError

from click import ClickException
from click import Path as clickPath
from click import command
from click import option
from click import version_option

from click import secho as clickSEcho

from pyimage2pdf import __version__ as pyImage2PdfVersion
from pyimage2pdf.Preferences import Preferences

from pyimage2pdf.PyImage2Pdf import OUTPUT_SUFFIX
from pyimage2pdf.PyImage2Pdf import PyImage2Pdf


class CommandClass:

    def __init__(self, inputFileName: Path, outputFileName: Path):
        self.logger: Logger = getLogger(__name__)

        self._inputFileName: Path = inputFileName

        if outputFileName is None:
            clickSEcho('Using input file name as base for output file name', bold=True)
            baseName: str = inputFileName.stem
            self._outputFileName: Path = Path(f'{baseName}.{OUTPUT_SUFFIX}')
            clickSEcho(f'Output file name is: {self._outputFileName}', bold=True)
        else:
            self._outputFileName = outputFileName

    def convert(self):
        pyimage2pdf: PyImage2Pdf = PyImage2Pdf()

        try:
            pyimage2pdf.convert(imagePath=self._inputFileName, pdfPath=self._outputFileName)
        except UnidentifiedImageError:
            raise ClickException('The input file does not appear to be an image file')


@command()
@version_option(version=f'{pyImage2PdfVersion}', message='%(version)s')
@option('-i', '--input-file',  required=True,  type=clickPath(readable=True, exists=True,  path_type=Path), help='The input image file name to convert.')
@option('-o', '--output-file', required=False, type=clickPath(writable=True,               path_type=Path), help='The output pdf file name.')
@option('-t', '--title',       required=False,  help='The title to put on pdf file')
def commandHandler(input_file: Path, output_file: Path, title: str):
    """
    \b
    This command converts input image files to pdf;  If
    you omit the output file name the command deduces the name
    based on the input file name
    """

    preferences: Preferences = Preferences()
    if title is not None:
        preferences.title = title
    commandClass: CommandClass = CommandClass(inputFileName=input_file, outputFileName=output_file)

    commandClass.convert()


if __name__ == "__main__":

    # commandHandler(['-i', 'tests/resources/images/CompactImageDump.png'])
    commandHandler(['-i', 'tests/resources/images/CompactImageDump.png', '--title', 'This is a custom title'])
    # commandHandler(['-i', 'tests/resources/images/Tailor.jpg', '-o', 'junk.pdf'])
    # commandHandler(['-i', 'tests/resources/images/CorruptedImage.png'])
    # commandHandler(['--help'])
    # commandHandler(['--version'])

==> pyimage2pdf-1.0.2-py3-none-any.whl: pyimage2pdf/CommandClass.py <==

from logging import Logger
from logging import getLogger

from pathlib import Path

from PIL import UnidentifiedImageError

from click import ClickException
from click import Path as clickPath
from click import command
from click import option
from click import version_option

from click import secho as clickSEcho

from pyimage2pdf import __version__ as pyImage2PdfVersion
from pyimage2pdf.Preferences import Preferences

from pyimage2pdf.PyImage2Pdf import OUTPUT_SUFFIX
from pyimage2pdf.PyImage2Pdf import PyImage2Pdf


class CommandClass:

    def __init__(self, inputFileName: Path, outputFileName: Path):
        self.logger: Logger = getLogger(__name__)

        self._inputFileName: Path = inputFileName

        if outputFileName is None:
            clickSEcho('Using input file name as base for output file name', bold=True)
            baseName: str = inputFileName.stem
            self._outputFileName: Path = Path(f'{baseName}.{OUTPUT_SUFFIX}')
            clickSEcho(f'Output file name is: {self._outputFileName}', bold=True)
        else:
            self._outputFileName = outputFileName

    def convert(self):
        pyimage2pdf: PyImage2Pdf = PyImage2Pdf()

        try:
            pyimage2pdf.convert(imagePath=self._inputFileName, pdfPath=self._outputFileName)
        except UnidentifiedImageError:
            raise ClickException('The input file does not appear to be an image file')


@command()
@version_option(version=f'{pyImage2PdfVersion}', message='%(version)s')
@option('-i', '--input-file',  required=True,  type=clickPath(readable=True, exists=True,  path_type=Path), help='The input image file name to convert.')
@option('-o', '--output-file', required=False, type=clickPath(writable=True,               path_type=Path), help='The output pdf file name.')
@option('-t', '--title',       required=False,  help='The title to put on the pdf file')
def commandHandler(input_file: Path, output_file: Path, title: str):
    """
    \b
    This command converts input image files to pdf;  If
    you omit the output file name the command deduces the name
    based on the input file name
    """

    preferences: Preferences = Preferences()
    if title is not None:
        preferences.title = title
    commandClass: CommandClass = CommandClass(inputFileName=input_file, outputFileName=output_file)

    commandClass.convert()


if __name__ == "__main__":

    # commandHandler(['-i', 'tests/resources/images/CompactImageDump.png'])
    commandHandler(['-i', 'tests/resources/images/CompactImageDump.png', '--title', 'This is a custom title'])
    # commandHandler(['-i', 'tests/resources/images/Tailor.jpg', '-o', 'junk.pdf'])
    # commandHandler(['-i', 'tests/resources/images/CorruptedImage.png'])
    # commandHandler(['--help'])
    # commandHandler(['--version'])
